//*****************************************************************************
// PS_Enforcer -- Modified Enforcer
// Created by mrbond113
//*****************************************************************************

class PS_Enforcer extends enforcer config(ProjSwap);

var config int PrimaryProj;
var config int SecondaryProj;
var string FireTag;

function TraceFire( float Accuracy )
{
	local vector RealOffset;

	RealOffset = FireOffset;
	FireOffset *= 0.35;
	if ( (SlaveEnforcer != None) || bIsSlave )
		Accuracy = FClamp(3*Accuracy,0.75,3);
	else if ( Owner.IsA('Bot') && !Bot(Owner).bNovice )
		Accuracy = FMax(Accuracy, 0.45);
    TraceFire2(Accuracy);
	FireOffset = RealOffset;
}

function TraceFire2( float Accuracy )
{
	local vector HitLocation, HitNormal, StartTrace, EndTrace, X,Y,Z;
	local actor Other;
	local Pawn PawnOwner;

	PawnOwner = Pawn(Owner);

	Owner.MakeNoise(PawnOwner.SoundDampening);
	GetAxes(PawnOwner.ViewRotation,X,Y,Z);
	StartTrace = Owner.Location + CalcDrawOffset() + FireOffset.X * X + FireOffset.Y * Y + FireOffset.Z * Z;
	AdjustedAim = PawnOwner.AdjustAim(1000000, StartTrace, 2*AimError, False, False);
	EndTrace = StartTrace + Accuracy * (FRand() - 0.5 )* Y * 1000
		+ Accuracy * (FRand() - 0.5 ) * Z * 1000;
	X = vector(AdjustedAim);
	EndTrace += (10000 * X);
	Other = PawnOwner.TraceShot(HitLocation,HitNormal,EndTrace,StartTrace);
	if((FireTag=="primary" && ProjectileClass != none) || (FireTag=="secondary" && AltProjectileClass != none))
    {
        if(FireTag=="primary")
        {
            Spawn(ProjectileClass,,, StartTrace + 16 * X,rotator(EndTrace - StartTrace));
        }
        else if(FireTag=="secondary")
        {
            Spawn(AltProjectileClass,,, StartTrace + 24 * X,rotator(EndTrace - StartTrace));
        }
    }
	else
    {
	ProcessTraceHit(Other, HitLocation, HitNormal, X,Y,Z);
	}
}

function Fire(float Value)
{
	if ( AmmoType == None )
	{
		// ammocheck
		GiveAmmo(Pawn(Owner));
	}
	if ( AmmoType.UseAmmo(1) )
	{
        FireTag="primary";
		GotoState('NormalFire');
		bCanClientFire = true;
		bPointing=True;
		ClientFire(value);
		if ( SlaveEnforcer != None )
			Pawn(Owner).PlayRecoil(2 * FiringSpeed);
		else if ( !bIsSlave )
			Pawn(Owner).PlayRecoil(FiringSpeed);
		TraceFire(0.2);
	}
}

function AltFire( float Value )
{
	bPointing=True;
	bCanClientFire = true;
	AltAccuracy = 0.4;
	if ( AmmoType == None )
	{
		// ammocheck
		GiveAmmo(Pawn(Owner));
	}
	if (AmmoType.AmmoAmount>0)
	{
		FireTag="secondary";
        if ( SlaveEnforcer != None )
			Pawn(Owner).PlayRecoil(3 * FiringSpeed);
		else if ( !bIsSlave )
			Pawn(Owner).PlayRecoil(1.5 * FiringSpeed);
		ClientAltFire(value);
		GotoState('AltFiring');
	}
}

simulated function PostBeginPlay()
{
    super.PostBeginPlay();
    switch(PrimaryProj)
    {
        case 0:
            ProjectileClass=None;
            break;
        case 1:
            ProjectileClass=class'ProjSwap.PS_SmallBioProj';
            break;
        case 2:
            ProjectileClass=class'ProjSwap.PS_LargeBioProj';
            break;
        case 3:
            ProjectileClass=class'ProjSwap.PS_ShockProj';
            break;
        case 4:
            ProjectileClass=class'ProjSwap.PS_PulseProj';
            break;
        case 5:
            ProjectileClass=class'ProjSwap.PS_RazorProj';
            break;
        case 6:
            ProjectileClass=class'ProjSwap.PS_RazorAltProj';
            break;
        case 7:
            ProjectileClass=class'ProjSwap.PS_FlakChunkProj';
            break;
        case 8:
            ProjectileClass=class'ProjSwap.PS_FlakShellProj';
            break;
        case 9:
            ProjectileClass=class'ProjSwap.PS_RocketProj';
            break;
        case 10:
            ProjectileClass=class'ProjSwap.PS_GrenadeProj';
            break;
        case 11:
            ProjectileClass=class'ProjSwap.PS_WarheadProj';
            break;
    }
    switch(SecondaryProj)
    {
        case 0:
            AltProjectileClass=None;
            break;
        case 1:
            AltProjectileClass=class'ProjSwap.PS_SmallBioProj';
            break;
        case 2:
            AltProjectileClass=class'ProjSwap.PS_LargeBioProj';
            break;
        case 3:
            AltProjectileClass=class'ProjSwap.PS_ShockProj';
            break;
        case 4:
            AltProjectileClass=class'ProjSwap.PS_PulseProj';
            break;
        case 5:
            AltProjectileClass=class'ProjSwap.PS_RazorProj';
            break;
        case 6:
            AltProjectileClass=class'ProjSwap.PS_RazorAltProj';
            break;
        case 7:
            AltProjectileClass=class'ProjSwap.PS_FlakChunkProj';
            break;
        case 8:
            AltProjectileClass=class'ProjSwap.PS_FlakShellProj';
            break;
        case 9:
            AltProjectileClass=class'ProjSwap.PS_RocketProj';
            break;
        case 10:
            AltProjectileClass=class'ProjSwap.PS_GrenadeProj';
            break;
        case 11:
            AltProjectileClass=class'ProjSwap.PS_WarheadProj';
            break;
    }
}
defaultproperties
{
}
